@@ -13,13 +13,15 @@ class Distro(Module):
         usr = kw['usr']
         pub = kw['pub']
 
-        user = target.User(usr)
+        distro = target.distro
+
+        user = distro.user(usr)
 
         path = f'/home/{usr}/.ssh'
         name = f'authorized_keys'
         full = f'{path}/{name}'
 
-        ok = target.Dir(
+        ok = distro.dir(
             path, mode='700', user=usr, group=user.group.name
         ).deploy()
 
@@ -28,7 +30,7 @@ class Distro(Module):
 
         target.send(pub, full)
 
-        ok = target.File(
+        ok = distro.file(
             full, mod='600', usr=usr, grp=user.group.name
         ).deploy()
 
